@@ -6,7 +6,7 @@ jishaku.features.baseclass
 
 The base Feature class that serves as the superclass of all feature components.
 
-:copyright: (c) 2021 Devon (Gorialis) R
+:copyright: (c) 2021 Devon (scarletcafe) R
 :license: MIT, see LICENSE for more details.
 
 """
@@ -14,12 +14,11 @@ The base Feature class that serves as the superclass of all feature components.
 import asyncio
 import collections
 import contextlib
-import sys
 import typing
 from datetime import datetime, timezone
 
-import discord
 from discord.ext import commands
+from typing_extensions import Concatenate, ParamSpec
 
 from jishaku.types import BotT, ContextA
 
@@ -29,12 +28,8 @@ __all__ = (
 )
 
 
-if typing.TYPE_CHECKING or discord.version_info >= (2, 0, 0):
-    _ConvertedCommand = commands.Command['Feature', typing.Any, typing.Any]
-    _ConvertedGroup = commands.Group['Feature', typing.Any, typing.Any]
-else:
-    _ConvertedCommand = commands.Command
-    _ConvertedGroup = commands.Group
+_ConvertedCommand = commands.Command['Feature', typing.Any, typing.Any]
+_ConvertedGroup = commands.Group['Feature', typing.Any, typing.Any]
 
 
 _FeatureCommandToCommand = typing.Callable[
@@ -53,16 +48,7 @@ _FeatureCommandToGroup = typing.Callable[
 ]
 
 T = typing.TypeVar('T')
-
-if sys.version_info < (3, 10):
-    from typing_extensions import Concatenate, ParamSpec
-    P = ParamSpec('P')
-    Task = asyncio.Task
-else:
-    Concatenate = typing.Concatenate  # pylint: disable=no-member
-    P = typing.ParamSpec('P')  # pylint: disable=no-member
-    Task = asyncio.Task[typing.Any]
-
+P = ParamSpec('P')
 GenericFeature = typing.TypeVar('GenericFeature', bound='Feature')
 
 
@@ -73,7 +59,7 @@ class CommandTask(typing.NamedTuple):
 
     index: int  # type: ignore
     ctx: ContextA
-    task: typing.Optional[Task]
+    task: typing.Optional['asyncio.Task[typing.Any]']
 
 
 class Feature(commands.Cog):
@@ -150,11 +136,11 @@ class Feature(commands.Cog):
 
             return command_type(**self.kwargs)(self.callback)
 
-    load_time: datetime = datetime.utcnow().replace(tzinfo=timezone.utc)
+    load_time: datetime = datetime.now(timezone.utc)
 
     def __init__(self, *args: typing.Any, **kwargs: typing.Any):
         self.bot: BotT = kwargs.pop('bot')
-        self.start_time: datetime = datetime.utcnow().replace(tzinfo=timezone.utc)
+        self.start_time: datetime = datetime.now(timezone.utc)
         self.tasks: typing.Deque[CommandTask] = collections.deque()
         self.task_count: int = 0
 
