@@ -6,7 +6,7 @@ jishaku.features.python
 
 The jishaku Python evaluation/execution commands.
 
-:copyright: (c) 2021 Devon (Gorialis) R
+:copyright: (c) 2021 Devon (scarletcafe) R
 :license: MIT, see LICENSE for more details.
 
 """
@@ -15,6 +15,7 @@ import asyncio
 import collections
 import inspect
 import io
+import sys
 import time
 import typing
 
@@ -24,10 +25,11 @@ from jishaku.codeblocks import Codeblock, codeblock_converter
 from jishaku.exception_handling import ReplResponseReactor
 from jishaku.features.baseclass import Feature
 from jishaku.flags import Flags
+from jishaku.formatting import MultilineFormatter
 from jishaku.functools import AsyncSender
-from jishaku.math import format_stddev
+from jishaku.math import format_bargraph, format_stddev
 from jishaku.paginators import PaginatorInterface, WrappedPaginator, use_file_check
-from jishaku.repl import AsyncCodeExecutor, Scope, all_inspections, create_tree, disassemble, get_var_dict_from_ctx
+from jishaku.repl import AsyncCodeExecutor, Scope, all_inspections, create_tree, disassemble, get_adaptive_spans, get_var_dict_from_ctx
 from jishaku.types import ContextA
 
 try:
@@ -156,17 +158,18 @@ class PythonFeature(Feature):
         arg_dict["_"] = self.last_result
         convertables: typing.Dict[str, str] = {}
 
-        for index, user in enumerate(ctx.message.mentions):
-            arg_dict[f"__user_mention_{index}"] = user
-            convertables[user.mention] = f"__user_mention_{index}"
+        if getattr(ctx, 'interaction', None) is None:
+            for index, user in enumerate(ctx.message.mentions):
+                arg_dict[f"__user_mention_{index}"] = user
+                convertables[user.mention] = f"__user_mention_{index}"
 
-        for index, channel in enumerate(ctx.message.channel_mentions):
-            arg_dict[f"__channel_mention_{index}"] = channel
-            convertables[channel.mention] = f"__channel_mention_{index}"
+            for index, channel in enumerate(ctx.message.channel_mentions):
+                arg_dict[f"__channel_mention_{index}"] = channel
+                convertables[channel.mention] = f"__channel_mention_{index}"
 
-        for index, role in enumerate(ctx.message.role_mentions):
-            arg_dict[f"__role_mention_{index}"] = role
-            convertables[role.mention] = f"__role_mention_{index}"
+            for index, role in enumerate(ctx.message.role_mentions):
+                arg_dict[f"__role_mention_{index}"] = role
+                convertables[role.mention] = f"__role_mention_{index}"
 
         return arg_dict, convertables
 
@@ -303,15 +306,15 @@ class PythonFeature(Feature):
                                     self.last_result = result
 
                                     send(await self.jsk_python_result_handling(ctx, result))
-                                    # Reduces likelyhood of hardblocking
-                                    await asyncio.sleep(0.01)
+                                    # Reduces likelihood of hardblocking
+                                    await asyncio.sleep(0.001)
 
                                 end = time.perf_counter()
                             finally:
                                 profile.disable()  # type: ignore
 
-                            # Reduces likelyhood of hardblocking
-                            await asyncio.sleep(0.01)
+                            # Reduces likelihood of hardblocking
+                            await asyncio.sleep(0.001)
 
                             count += 1
                             timings.append(end - start)
@@ -320,8 +323,8 @@ class PythonFeature(Feature):
 
                             for function in profile.code_map.values():  # type: ignore
                                 for timing in function.values():  # type: ignore
-                                    line_timings[timing.lineno].append(timing.total_time * profile.timer_unit)  # type: ignore
-                                    ioless_time += timing.total_time * profile.timer_unit  # type: ignore
+                                    line_timings[timing['lineno']].append(timing['total_time'] * profile.timer_unit)  # type: ignore
+                                    ioless_time += timing['total_time'] * profile.timer_unit  # type: ignore
 
                             ioless_timings.append(ioless_time)
 
@@ -333,29 +336,16 @@ class PythonFeature(Feature):
                         linecache = executor.create_linecache()
                         lines: typing.List[str] = []
 
-                        RELATIVE_MAPPINGS = (
-                            (0 / 8, "\N{LEFT ONE EIGHTH BLOCK}", '\u001b[32m'),
-                            (1 / 8, "\N{LEFT ONE QUARTER BLOCK}", '\u001b[32m'),
-                            (2 / 8, "\N{LEFT THREE EIGHTHS BLOCK}", '\u001b[32m'),
-                            (3 / 8, "\N{LEFT HALF BLOCK}", '\u001b[33m'),
-                            (4 / 8, "\N{LEFT FIVE EIGHTHS BLOCK}", '\u001b[33m'),
-                            (5 / 8, "\N{LEFT THREE QUARTERS BLOCK}", '\u001b[33m'),
-                            (6 / 8, "\N{LEFT SEVEN EIGHTHS BLOCK}", '\u001b[31m'),
-                            (7 / 8, "\N{FULL BLOCK}", '\u001b[31m'),
-                        )
-
                         for lineno in sorted(line_timings.keys()):
                             timing = line_timings[lineno]
                             max_time = max(timing)
-                            mapping = RELATIVE_MAPPINGS[0]
+                            percentage = max_time / max_line_time
+                            blocks = format_bargraph(percentage, 5)
 
-                            for maybe_mapping in RELATIVE_MAPPINGS:
-                                if (max_time / max_line_time) > maybe_mapping[0]:
-                                    mapping = maybe_mapping
+                            line = f"{format_stddev(timing)} {blocks} {linecache[lineno - 1] if lineno <= len(linecache) else ''}"
+                            color = '\u001b[31m' if percentage > 6 / 8 else '\u001b[33m' if percentage > 3 / 8 else '\u001b[32m'
 
-                            line = f"{format_stddev(timing)} {mapping[1]} {linecache[lineno - 1] if lineno <= len(linecache) else ''}"
-
-                            lines.append('\u001b[0m' + mapping[2] + line if Flags.use_ansi(ctx) else line)
+                            lines.append('\u001b[0m' + color + line if Flags.use_ansi(ctx) else line)
 
                         await ctx.send(
                             content="\n".join([
@@ -416,3 +406,57 @@ class PythonFeature(Feature):
                 filename="ast.ansi",
                 fp=io.BytesIO(text.encode('utf-8'))
             ))
+
+    if sys.version_info >= (3, 11):
+        @Feature.Command(parent="jsk", name="specialist")
+        async def jsk_specialist(self, ctx: ContextA, *, argument: codeblock_converter):  # type: ignore
+            """
+            Direct evaluation of Python code.
+            """
+
+            if typing.TYPE_CHECKING:
+                argument: Codeblock = argument  # type: ignore
+
+            arg_dict, convertables = self.jsk_python_get_convertables(ctx)
+            scope = self.scope
+
+            try:
+                async with ReplResponseReactor(ctx.message):
+                    with self.submit(ctx):
+                        executor = AsyncCodeExecutor(argument.content, scope, arg_dict=arg_dict, convertables=convertables)
+                        async for send, result in AsyncSender(executor):  # type: ignore
+                            send: typing.Callable[..., None]
+                            result: typing.Any
+
+                            if result is None:
+                                continue
+
+                            self.last_result = result
+
+                            send(await self.jsk_python_result_handling(ctx, result))
+
+                        formatter = MultilineFormatter(argument.content, add_newline=True)
+
+                        for (
+                            index,
+                            (instruction, line, span, specialized, adaptive)
+                        ) in enumerate(get_adaptive_spans(executor.function.__code__)):  # pylint: disable=protected-access
+                            if 0 <= line - 1 < len(formatter.lines):
+                                formatter.add_annotation(
+                                    line - 1,
+                                    instruction.opname,
+                                    span,
+                                    (index % 6) + 31,
+                                    None,
+                                    45 if specialized else 46 if adaptive else None
+                                )
+
+                        text = formatter.output(True, Flags.use_ansi(ctx))
+
+                        await ctx.send(file=discord.File(
+                            filename="specialist.ansi",
+                            fp=io.BytesIO(text.encode('utf-8'))
+                        ))
+
+            finally:
+                scope.clear_intersection(arg_dict)
