@@ -6,7 +6,7 @@ jishaku.features.root_command
 
 The jishaku root command.
 
-:copyright: (c) 2021 Devon (Gorialis) R
+:copyright: (c) 2021 Devon (scarletcafe) R
 :license: MIT, see LICENSE for more details.
 
 """
@@ -14,6 +14,11 @@ The jishaku root command.
 import sys
 import typing
 
+try:
+    from importlib.metadata import distribution, packages_distributions
+except ImportError:
+    from importlib_metadata import distribution, packages_distributions
+
 import discord
 from discord.ext import commands
 
@@ -29,11 +34,6 @@ try:
 except ImportError:
     psutil = None
 
-try:
-    from importlib.metadata import distribution, packages_distributions
-except ImportError:
-    from importlib_metadata import distribution, packages_distributions  # type: ignore
-
 
 class RootCommand(Feature):
     """
@@ -106,8 +106,9 @@ class RootCommand(Feature):
                     "to query process information."
                 )
                 summary.append("")  # blank line
-
-        cache_summary = f"{len(self.bot.guilds)} guild(s) and {len(self.bot.users)} user(s)"
+        s_for_guilds = "" if len(self.bot.guilds) == 1 else "s"
+        s_for_users = "" if len(self.bot.users) == 1 else "s"
+        cache_summary = f"{len(self.bot.guilds)} guild{s_for_guilds} and {len(self.bot.users)} user{s_for_users}"
 
         # Show shard settings to summary
         if isinstance(self.bot, discord.AutoShardedClient):
@@ -136,24 +137,19 @@ class RootCommand(Feature):
         else:
             message_cache = "Message cache is disabled"
 
-        if discord.version_info >= (1, 5, 0):
-            remarks = {
-                True: 'enabled',
-                False: 'disabled',
-                None: 'unknown'
-            }
+        remarks = {
+            True: 'enabled',
+            False: 'disabled',
+            None: 'unknown'
+        }
 
-            *group, last = (
-                f"{intent.replace('_', ' ')} intent is {remarks.get(getattr(self.bot.intents, intent, None))}"
-                for intent in
-                ('presences', 'members', 'message_content')
-            )
+        *group, last = (
+            f"{intent.replace('_', ' ')} intent is {remarks.get(getattr(self.bot.intents, intent, None))}"
+            for intent in
+            ('presences', 'members', 'message_content')
+        )
 
-            summary.append(f"{message_cache}, {', '.join(group)}, and {last}.")
-        else:
-            guild_subscriptions = f"guild subscriptions are {'enabled' if self.bot._connection.guild_subscriptions else 'disabled'}"  # type: ignore
-
-            summary.append(f"{message_cache} and {guild_subscriptions}.")
+        summary.append(f"{message_cache}, {', '.join(group)}, and {last}.")
 
         # pylint: enable=protected-access
 
@@ -249,7 +245,7 @@ class RootCommand(Feature):
 
         if task.ctx.command:
             await ctx.send(f"Cancelled task {task.index}: `{task.ctx.command.qualified_name}`,"
-                           f" invoked at {task.ctx.message.created_at.strftime('%Y-%m-%d %H:%M:%S')} UTC")
+                           f" invoked {discord.utils.format_dt(task.ctx.message.created_at, 'R')}")
         else:
             await ctx.send(f"Cancelled task {task.index}: unknown,"
-                           f" invoked at {task.ctx.message.created_at.strftime('%Y-%m-%d %H:%M:%S')} UTC")
+                           f" invoked {discord.utils.format_dt(task.ctx.message.created_at, 'R')}")
