@@ -6,23 +6,19 @@ jishaku.functools
 
 Function-related tools for Jishaku.
 
-:copyright: (c) 2021 Devon (Gorialis) R
+:copyright: (c) 2021 Devon (scarletcafe) R
 :license: MIT, see LICENSE for more details.
 
 """
 
 import asyncio
 import functools
-import sys
 import typing
 
-T = typing.TypeVar('T')
+from typing_extensions import ParamSpec
 
-if sys.version_info < (3, 10):
-    from typing_extensions import ParamSpec
-    P = ParamSpec('P')
-else:
-    P = typing.ParamSpec('P')  # pylint: disable=no-member
+T = typing.TypeVar('T')
+P = ParamSpec('P')
 
 
 def executor_function(sync_function: typing.Callable[P, T]) -> typing.Callable[P, typing.Awaitable[T]]:
