@@ -6,15 +6,13 @@ jishaku.meta
 
 Meta information about jishaku.
 
-:copyright: (c) 2021 Devon (Gorialis) R
+:copyright: (c) 2021 Devon (scarletcafe) R
 :license: MIT, see LICENSE for more details.
 
 """
 
 import typing
 
-import pkg_resources
-
 __all__ = (
     '__author__',
     '__copyright__',
@@ -35,14 +33,11 @@ class VersionInfo(typing.NamedTuple):
     serial: int
 
 
-version_info = VersionInfo(major=2, minor=5, micro=1, releaselevel='final', serial=0)
+version_info = VersionInfo(major=2, minor=6, micro=3, releaselevel='final', serial=0)
 
-__author__ = 'Gorialis'
-__copyright__ = 'Copyright 2021 Devon (Gorialis) R'
+__author__ = 'scarletcafe'
+__copyright__ = 'Copyright 2021 Devon (scarletcafe) R'
 __docformat__ = 'restructuredtext en'
 __license__ = 'MIT'
 __title__ = 'jishaku'
 __version__ = '.'.join(map(str, (version_info.major, version_info.minor, version_info.micro)))
-
-# This ensures that when jishaku is reloaded, pkg_resources requeries it to provide correct version info
-pkg_resources.working_set.by_key.pop('jishaku', None)  # type: ignore
